@@ -176,6 +176,91 @@ class Cable:
     Tc0_Nb3Sn: np.ndarray = np.array([])
     Bc20_Nb3Sn: np.ndarray = np.array([])
 
+def CompareLEDETParameters(FileA, FileB):
+    Diff = 0
+
+    P_a = ParametersLEDET()
+    P_a.readLEDETExcel(FileA)
+    P_b = ParametersLEDET()
+    P_b.readLEDETExcel(FileB)
+
+    print("Starting Comparison of A: ({}) and B: ({})".format(FileA, FileB))
+
+    ## Check Inputs
+    for attribute in P_a.Inputs.__annotations__:
+        Block = 1
+        CC = 0
+
+        P_a_a = P_a.getAttribute("Inputs", attribute)
+        P_b_a = P_b.getAttribute("Inputs", attribute)
+        if isinstance(P_a_a, float):
+            if P_a_a != P_b_a:
+                if Block: print("Found difference in Parameter {}".format(attribute))
+                Block = 0
+                Diff = 1
+        elif len(P_a_a) != len(P_b_a):
+            Diff = 1
+            if Block:
+                Block = 0
+                print('Parameter {} of A, {} has not the same length as Parameter of B, {}'.format(attribute, len(P_a_a), len(P_b_a)))
+        else:
+            for k in range(len(P_a_a)):
+                try:
+                    if P_a_a[k] != P_b_a[k]:
+                        Diff = 1
+                        if Block:
+                            print("Found difference in Parameter {}".format(attribute))
+                            Block = 0
+                        print("Position: {}".format(k))
+                except:
+                    for j in range(P_a_a.shape[1]):
+                        if P_a_a[k,j] != P_b_a[k,j]:
+                            Diff = 1
+                            if Block:
+                                print("Found difference in Parameter {}".format(attribute))
+                                Block = 0
+                            if CC<5:
+                                print("Position: Row: {}, Col: {}".format(k, j))
+                                CC = CC +1
+                            elif CC==5:
+                                print("Many errors in this array. Continue to next.")
+                                CC = CC + 1
+    ## Check Options
+    for attribute in P_a.Options.__annotations__:
+        Block = 1
+        P_a_a = P_a.getAttribute("Options", attribute)
+        P_b_a = P_b.getAttribute("Options", attribute)
+        if isinstance(P_a_a, float):
+            if P_a_a != P_b_a:
+                Diff = 1
+                if Block: print("Found difference in Parameter {}".format(attribute))
+                Block = 0
+        elif len(P_a_a) != len(P_b_a):
+            Diff = 1
+            if Block:
+                Block = 0
+                print('Parameter {} of A, {} has not the same length as Parameter of B, {}'.format(attribute, len(P_a_a), len(P_b_a)))
+        else:
+            for k in range(len(P_a_a)):
+                try:
+                    if P_a_a[k] != P_b_a[k]:
+                        if Block:
+                            print("Found difference in Parameter {}".format(attribute))
+                            Block = 0
+                        print("Position: {}".format(k))
+                        Diff = 1
+                except:
+                    for j in range(P_a_a.shape[1]):
+                        if P_a_a[k,j] != P_b_a[k,j]:
+                            if Block:
+                                print("Found difference in Parameter {}".format(attribute))
+                                Block = 0
+                            print("Position: Row: {}, Col: {}".format(k, j))
+                            Diff = 1
+
+    if Diff==0:
+        print("Files are equal.")
+
 class ParametersLEDET:
     '''
         Class of LEDET parameters
@@ -230,62 +315,80 @@ class ParametersLEDET:
         for i in range(worksheetInputs.nrows):
             self.variablesInputs[str(worksheetInputs.cell(i, 1).value)] = str(worksheetInputs.cell(i, 0).value)
             attribute = worksheetInputs.cell(i, 1).value
-            if (attribute == ''):
-                if (type(worksheetInputs.cell(i, 2).value) != str):
+            try:
+                if (attribute == ''):
+                    if (type(worksheetInputs.cell(i, 2).value) != str):
+                        values = worksheetInputs.row_values(i, 2)
+                        values = np.array([k for k in values if(str(k))])
+                        current = self.getAttribute(self.Inputs, lastAttribute)
+                        current = np.vstack((current, values))
+                        self.setAttribute(self.Inputs, lastAttribute, current)
+                    else:
+                        continue
+                elif (type(self.getAttribute(self.Inputs, attribute)) == np.ndarray):
+                    lastAttribute = attribute
                     values = worksheetInputs.row_values(i, 2)
                     values = np.array([k for k in values if(str(k))])
-                    current = self.getAttribute(self.Inputs, lastAttribute)
-                    current = np.vstack((current, values))
-                    self.setAttribute(self.Inputs, lastAttribute, current)
+                    self.setAttribute(self.Inputs, attribute, values)
                 else:
-                    continue
-            elif (type(self.getAttribute(self.Inputs, attribute)) == np.ndarray):
-                lastAttribute = attribute
-                values = worksheetInputs.row_values(i, 2)
-                values = np.array([k for k in values if(str(k))])
-                self.setAttribute(self.Inputs, attribute, values)
-            else:
-                value = worksheetInputs.cell(i, 2).value
-                self.setAttribute(self.Inputs, attribute, value)
+                    value = worksheetInputs.cell(i, 2).value
+                    self.setAttribute(self.Inputs, attribute, value)
+            except TypeError as e:
+                if attribute in self.Inputs.__annotations__: raise e
+                print("Error with attribute: {}, continuing.".format(attribute))
         #Options
         worksheetOptions = workbookVariables.sheet_by_name('Options')
         for i in range(worksheetOptions.nrows):
             self.variablesOptions[str(worksheetOptions.cell(i, 1).value)] = str(worksheetOptions.cell(i, 0).value)
             attribute = worksheetOptions.cell(i, 1).value
-            if (type(self.getAttribute(self.Options, attribute)) == np.ndarray):
-                values = worksheetOptions.row_values(i, 2)
-                values = np.array([k for k in values if(str(k))])
-                self.setAttribute(self.Options, attribute, values)
-            else:
-                value = worksheetOptions.cell(i, 2).value
-                self.setAttribute(self.Options, attribute, value)
-        #Plots
+            try:
+                if (type(self.getAttribute(self.Options, attribute)) == np.ndarray):
+                    values = worksheetOptions.row_values(i, 2)
+                    values = np.array([k for k in values if(str(k))])
+                    self.setAttribute(self.Options, attribute, values)
+                else:
+                    value = worksheetOptions.cell(i, 2).value
+                    self.setAttribute(self.Options, attribute, value)
+            except  TypeError as e:
+                if attribute in self.Options.__annotations__: raise e
+                print("Error with attribute: {}, continuing.".format(attribute))
+                #Plots
         worksheetPlots = workbookVariables.sheet_by_name('Plots')
         for i in range(worksheetPlots.nrows):
             self.variablesPlots[str(worksheetPlots.cell(i, 1).value)] = str(worksheetPlots.cell(i, 0).value)
             attribute = worksheetPlots.cell(i, 1).value
-            if (type(self.getAttribute(self.Plots, attribute)) == np.ndarray):
-                values = worksheetPlots.row_values(i, 2)
-                values = np.array([k for k in values if(str(k))])
-                self.setAttribute(self.Plots, attribute, values)
-            else:
-                try:
-                    value = worksheetPlots.cell(i, 2).value
-                except:
-                    value = ''
-                self.setAttribute(self.Plots, attribute, value)
+            try:
+                if (type(self.getAttribute(self.Plots, attribute)) == np.ndarray):
+                    values = worksheetPlots.row_values(i, 2)
+                    values = np.array([k for k in values if(str(k))])
+                    self.setAttribute(self.Plots, attribute, values)
+                else:
+                    try:
+                        value = worksheetPlots.cell(i, 2).value
+                    except:
+                        value = ''
+                    self.setAttribute(self.Plots, attribute, value)
+            except  TypeError as e:
+                print("Error with attribute: {}, continuing.".format(attribute))
         # Variables
-        worksheetVariables = workbookVariables.sheet_by_name('Variables')
-        for i in range(worksheetVariables.nrows):
-            self.variablesVariables[str(worksheetVariables.cell(i, 1).value)] = str(worksheetVariables.cell(i, 0).value)
-            attribute = worksheetVariables.cell(i, 1).value
-            if (type(self.getAttribute(self.Variables, attribute)) == np.ndarray):
-                values = worksheetVariables.row_values(i, 2)
-                values = np.array([k for k in values if(str(k))])
-                self.setAttribute(self.Variables, attribute, values)
-            else:
-                value = worksheetVariables.cell(i, 2).value
-                self.setAttribute(self.Variables, attribute, value)
+        try:
+            worksheetVariables = workbookVariables.sheet_by_name('Variables')
+            for i in range(worksheetVariables.nrows):
+                self.variablesVariables[str(worksheetVariables.cell(i, 1).value)] = str(worksheetVariables.cell(i, 0).value)
+                attribute = worksheetVariables.cell(i, 1).value
+                try:
+                    if (type(self.getAttribute(self.Variables, attribute)) == np.ndarray):
+                        values = worksheetVariables.row_values(i, 2)
+                        values = np.array([k for k in values if(str(k))])
+                        self.setAttribute(self.Variables, attribute, values)
+                    else:
+                        value = worksheetVariables.cell(i, 2).value
+                        self.setAttribute(self.Variables, attribute, value)
+                except TypeError as e:
+                    if attribute in self.Variables.__annotations__: raise e
+                    print("Error with attribute: {}, continuing.".format(attribute))
+        except xlrd.biffh.XLRDError as e:
+            print("Error while reading Variables. Please check!")
 
     def __init__(self):
         self.Inputs = LEDETInputs()
