@@ -1,5 +1,6 @@
 from steam_nb_api.ledet.ParameterSweep import *
 from steam_nb_api.ledet.ParametersLEDET import ParametersLEDET
+from steam_nb_api.ledet.ParametersLEDET import *
 import pandas as pd
 from steam_nb_api.ledet.Simulation import RunSimulations
 from steam_nb_api.ledet.SimulationEvaluation import EvaluateSimulations
@@ -153,10 +154,74 @@ def testvQ():
 
 def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim):
     a = QuenchPlanAnalysis(FileName_TDMS, FileName_Sim)
-    a.QuenchPlanAnalysis()
+    Coil108 = [[],
+               np.concatenate((np.linspace(29, 45, 17), np.linspace(229, 245, 17))),
+               np.concatenate((np.linspace(46, 49, 4), np.linspace(246, 249, 4))),
+               [],
+               np.array([50]),
+               [],
+               np.array([250]),
+               [],
+               [],
+               np.array([28]),
+               [],
+               np.array([228]),
+               np.concatenate((np.linspace(17, 27, 11), np.linspace(217, 227, 11))),
+               np.concatenate((np.linspace(1, 16, 16), np.linspace(201, 216, 16)))]
+
+    Coil109 = [[],
+               np.concatenate((np.linspace(329, 345, 17), np.linspace(129, 145, 17))),
+               np.concatenate((np.linspace(146, 149, 4), np.linspace(346, 349, 4))),
+               [],
+               np.array([150]),
+               [],
+               np.array([350]),
+               [],
+               [],
+               np.array([128]),
+               [],
+               np.array([328]),
+               np.concatenate((np.linspace(117, 127, 11), np.linspace(317, 327, 11))),
+               np.concatenate((np.linspace(101, 116, 16), np.linspace(301, 316, 16)))]
+
+    Coil110 = [[],
+               np.concatenate((np.linspace(79, 95, 17), np.linspace(279, 295, 17))),
+               np.concatenate((np.linspace(96, 99, 4), np.linspace(296, 299, 4))),
+               [],
+               np.array([100]),
+               [],
+               np.array([300]),
+               [],
+               [],
+               np.array([78]),
+               [],
+               np.array([278]),
+               np.concatenate((np.linspace(267, 277, 11), np.linspace(67, 77, 11))),
+               np.concatenate((np.linspace(51, 66, 16), np.linspace(251, 266, 16)))]
+
+    Coil111 = [[],
+               np.concatenate((np.linspace(179, 195, 17), np.linspace(379, 395, 17))),
+               np.concatenate((np.linspace(196, 199, 4), np.linspace(396, 399, 4))),
+               [],
+               np.array([200]),
+               [],
+               np.array([400]),
+               [],
+               [],
+               np.array([178]),
+               [],
+               np.array([378]),
+               np.concatenate((np.linspace(367, 377, 11), np.linspace(167, 177, 11))),
+               np.concatenate((np.linspace(151, 166, 16), np.linspace(351, 366, 16)))]
+    a.ProvideTurnsToCoilStructure([Coil108,Coil109,Coil110,Coil111])
+    a.QuenchPlanAnalysis(Plot = 1)
     return a
 
 # testConsistencyChecks()
+
+CompareLEDETParameters("C:\cernbox\LEDET_MT\LEDET\MQXFS4b\Input\MQXFS4b_0.xlsx", "C:\cernbox\MasterThesis\QuenchPlans\MQXF_V2_2924.xlsx")
+# CompareLEDETParameters("C:\\cernbox\\steam-notebook-api\\test\\ledet\\resources\\TestFile_1.xlsx", "C:\\cernbox\\steam-notebook-api\\test\\ledet\\TestFile1.xlsx")
+
 # test_readLEDETExcel()
 # test_setgetAttributes()
 # test_permutations()
@@ -165,9 +230,10 @@ def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim):
 
 # CompleteRun()
 
-td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\MQXFS4b\\HCMQXSM001-CR000042__H1810111001_a001(0).tdms"
-sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_5.mat"
-a = testQuenchPlanAnalysis(td_data, sim_data)
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\MQXFS4b\\HCMQXSM001-CR000042__H1810171217_a041(0).tdms"
+# sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_27.mat"
+# a = testQuenchPlanAnalysis(td_data, sim_data)
+
 
 # a = ParametersLEDET()
 # a.readLEDETExcel(testfile7)
