@@ -1,12 +1,12 @@
 import os
 import numpy as np
 import pandas as pd
+import re
 from scipy.interpolate import interp1d
 from tqdm import tqdm
 from matplotlib import cm
 from mpl_toolkits.mplot3d import Axes3D
 import matplotlib.cm as cm
-import matplotlib.pylab as pl
 from matplotlib.collections import PolyCollection
 import matplotlib.pyplot as plt
 from matplotlib import colors as mcolors
@@ -24,12 +24,17 @@ class TDMSdata:
     Tolerance: float = 20.0
     groupHF:  nptdms.GroupObject = nptdms.GroupObject('HF')
     groupMF: nptdms.GroupObject = nptdms.GroupObject('MF')
+    VoltageVertices: np.ndarray = np.array([])
     TimeFrame_MF: np.ndarray = np.array([])
     t_steps_MF:  float = 0.0
     t_d_MF: float = 0.0
     trigger_PC: int = 0
     I_DCCT_MF: np.ndarray = np.array([])
     I_DCCT_HF: np.ndarray = np.array([])
+    I_CLIQ: np.ndarray = np.array([])
+    U_CLIQ: np.ndarray = np.array([])
+    I_QH: np.ndarray = np.array([])
+    U_QH: np.ndarray = np.array([])
     QL1: float = 0.0
     QL2: float = 0.0
 
@@ -41,6 +46,9 @@ class SIMdata:
     I_CoilSections: np.ndarray = np.array([])
     I_CLIQ: np.ndarray = np.array([])
     directionsCLIQ: np.ndarray = np.array([])
+    U_CLIQ: np.ndarray = np.array([])
+    I_QH: np.ndarray = np.array([])
+    U_QH: np.ndarray = np.array([])
     QL1: float = 0.0
     QL2: float = 0.0
 
@@ -401,6 +409,8 @@ class QuenchPlanAnalysis():
         self.beforePC = 0.1
         self.Colors = self.__generateColors()
 
+        self.MergedVoltages = {}
+
         self.SIMdata = SIMdata()
         self.SIMdata.FileName = FileNameSIMData
         self.__CreateSIMDataObject()
@@ -412,8 +422,6 @@ class QuenchPlanAnalysis():
         self.__calculateAllQuenchIntegrals()
 
     def __generateColors(self):
-        # n = 15
-        # colors = pl.cm.jet(np.linspace(0,1,n))
         # setting colors for plotting
         col = mcolors.TABLEAU_COLORS.keys()
         col2 = mcolors.BASE_COLORS.keys()
@@ -430,6 +438,59 @@ class QuenchPlanAnalysis():
             colors = colors + [c]
         return colors
 
+    def __FillHeaterArrays(self, Heaters, trigger_shoot):
+        Heat_len = len(self.TDMSdata.groupMF[Heaters[0]].data[trigger_shoot:])
+        if Heaters[0].startswith('I'): self.TDMSdata.I_QH = np.zeros((len(Heaters), Heat_len))
+        elif Heaters[0].startswith('U'): self.TDMSdata.U_QH = np.zeros((len(Heaters), Heat_len))
+        for k in Heaters:
+            order = int(k[-1])
+            if Heaters[0].startswith('I'): self.TDMSdata.I_QH[order-1] = self.TDMSdata.groupMF[k].data[trigger_shoot:]
+            elif Heaters[0].startswith('U'): self.TDMSdata.U_QH[order-1] = self.TDMSdata.groupMF[k].data[trigger_shoot:]
+
+    def __CreateVoltageVertices(self):
+        ## 1. Extract all channels that are relevant
+        temp_Sections = re.compile("([a-zA-Z]+)([0-9]+)([a-zA-Z]+)([0-9]+)([a-zA-Z]+)([0-9]+)")
+        temp_Coils = re.compile("([0-9]+)([a-zA-Z]+)")
+        CSections = []
+        Coils = []
+        Coils_Diff = []
+
+        for channel in self.TDMSdata.groupMF.channels():
+            if channel.properties['TransducerType'] == 'vtaps':
+                chName = channel.name.replace("_"," ")
+                chName = chName.replace("-"," ")
+                chName = chName.replace(" ", "")
+                try:
+                    res = temp_Sections.match(chName).groups()
+                    ChN = res + (str(res[0]+res[1]+'_'+res[2]+res[3]+"_"+res[4]+res[5]),)+ (channel.name,)
+                    CSections.append(ChN)
+                except:
+                    pass
+                if chName.startswith("Vcoil"):
+                    try:
+                        res = temp_Coils.match(chName[5:]).groups()
+                        ChN = res + (channel.name,)
+                        Coils_Diff.append(ChN)
+                    except:
+                        Coils.append((chName[5:], channel.name))
+
+        ## 2. order them in coils
+        def getKey0(item):
+            return item[0]
+        def getKey1(item):
+            return item[1]
+        CSections = sorted(CSections, key=getKey1)
+        Coils = sorted(Coils, key=getKey0)
+        Coils_Diff = sorted(Coils_Diff, key=getKey0)
+
+        self.TDMSdata.VoltageVertices = CSections
+        #for index, tuple in enumerate(CSections):
+        #    self.TDMSdata.VoltageVertices = np.append(self.TDMSdata.VoltageVertices,tuple[6])
+
+        ##TODO: also construct sth. for Diffs and Coils
+
+        return
+
     def __CreateTDMSDataObject(self):
         tdms_file = TdmsFile.read(self.TDMSdata.FileName)
         ## Save groups
@@ -439,6 +500,8 @@ class QuenchPlanAnalysis():
             else: print("Don't understand group: ", group)
 
         ## Pick channels and store conveniently
+        I_Heaters = []
+        U_Heaters = []
         for channel in self.TDMSdata.groupHF.channels():
             if channel.name == 'IDCCT_HF': self.TDMSdata.I_DCCT_HF = channel.data
         for channel in self.TDMSdata.groupMF.channels():
@@ -448,13 +511,24 @@ class QuenchPlanAnalysis():
                 self.TDMSdata.t_d_MF = channel.properties['wf_increment']
             if channel.name == 'Trigger_PC':
                 trigger_data = channel.data
+            if channel.name == 'I Cliq':self.TDMSdata.I_CLIQ = channel.data
+            if channel.name == 'V Cliq': self.TDMSdata.U_CLIQ = channel.data
+            if channel.name.startswith("I_Heater"): I_Heaters.append(channel.name)
+            if channel.name.startswith("U_Heater"): U_Heaters.append(channel.name)
         ## Set up Timeframe
         self.TDMSdata.TimeFrame_MF = np.linspace(0,self.TDMSdata.t_steps_MF*self.TDMSdata.t_d_MF, int(self.TDMSdata.t_steps_MF))
+        #self.TDMSdata.goupHF['IDCCT_HF'].time_track()
         trigger_shoot = np.gradient(trigger_data, self.TDMSdata.t_d_MF)
         trigger_shoot = np.where(abs(trigger_shoot)>self.TDMSdata.Tolerance)[0][0]-int(self.beforePC/self.TDMSdata.t_d_MF)
         self.TDMSdata.trigger_PC = int(self.beforePC/self.TDMSdata.t_d_MF)
         self.TDMSdata.TimeFrame_MF = self.TDMSdata.TimeFrame_MF[trigger_shoot:]-self.TDMSdata.TimeFrame_MF[trigger_shoot]
         self.TDMSdata.I_DCCT_MF = self.TDMSdata.I_DCCT_MF[trigger_shoot:]
+        self.TDMSdata.I_CLIQ = self.TDMSdata.I_CLIQ[trigger_shoot:]
+        self.TDMSdata.U_CLIQ = self.TDMSdata.U_CLIQ[trigger_shoot:]
+        self.__FillHeaterArrays(I_Heaters, trigger_shoot)
+        self.__FillHeaterArrays(U_Heaters, trigger_shoot)
+
+        self.__CreateVoltageVertices()
         return
 
     def __CreateSIMDataObject(self):
@@ -475,6 +549,12 @@ class QuenchPlanAnalysis():
             self.SIMdata.I_CoilSections = self.SIMdata.I_CoilSections[:, trigger_shoot:]
             self.SIMdata.I_CLIQ = self.SIMdata.I_CLIQ[trigger_shoot:]
             self.SIMdata.directionsCLIQ = np.array(f.get("directionCurrentCLIQ"))
+            U_CLIQ = np.array(f.get("Uc"))
+            self.SIMdata.U_CLIQ = U_CLIQ[:][trigger_shoot:]
+            I_QH = np.array(f.get("I_QH"))
+            self.SIMdata.I_QH = I_QH[:][trigger_shoot:]
+            U_QH = np.array(f.get("U_QH"))
+            self.SIMdata.U_QH = U_QH[:][trigger_shoot:]
         else:
             print("Please provide .mat file for Simulation.")
 
@@ -492,12 +572,34 @@ class QuenchPlanAnalysis():
             idxC = np.where(self.SIMdata.directionsCLIQ > 0)[0][0]
             self.SIMdata.QL1 = self.__calculateQuenchIntegral(self.SIMdata.TimeFrame[self.SIMdata.trigger_PC:,0], self.SIMdata.I_CoilSections[self.SIMdata.trigger_PC:,idxC])
         else:
-            print("IUhm")
             self.SIMdata.QL1 = self.__calculateQuenchIntegral(self.SIMdata.TimeFrame[self.SIMdata.trigger_PC:,0], self.SIMdata.I_CoilSections[self.SIMdata.trigger_PC:,0])
 
         ## QL Integral 2
         ## tbd
 
+    def GetTDMSCoilStructure(self):
+        CoilCount = 0
+        for i in range(len(self.TDMSdata.VoltageVertices)):
+            temp = self.TDMSdata.VoltageVertices[i][1]
+            if CoilCount != temp:
+                CoilCount = temp
+                print("*** Coil: ", CoilCount)
+            print("-->",self.TDMSdata.VoltageVertices[i][2]+self.TDMSdata.VoltageVertices[i][3],
+                  " to ", self.TDMSdata.VoltageVertices[i][4]+self.TDMSdata.VoltageVertices[i][5])
+        return
+
+    def ProvideTurnsToCoilStructure(self, Coil):
+        VerticeCount = 0
+        for i in range(len(Coil)):
+            CS = Coil[i]
+            for j in range(len(CS)):
+                if len(CS[j]) == 0: continue
+                else:
+                    Vertice = self.TDMSdata.VoltageVertices[VerticeCount][6]
+                    self.MergedVoltages[Vertice] = CS[j]
+                    VerticeCount = VerticeCount +1
+        return
+
     def QuenchPlanAnalysis(self, Plot = 0):
         # Plot current together
         if Plot:
@@ -509,8 +611,10 @@ class QuenchPlanAnalysis():
                 ax.plot(self.SIMdata.TimeFrame, self.SIMdata.I_CoilSections[:,i], color= self.Colors[i])
             if sum(self.SIMdata.I_CLIQ) != 0:
                 ax.plot(self.SIMdata.TimeFrame, self.SIMdata.I_CLIQ, color= self.Colors[self.SIMdata.I_CoilSections.shape[1]+1])
-                legend.append("$I_{CLIQ}$")
-            ax.plot(self.TDMSdata.TimeFrame_MF, self.TDMSdata.I_DCCT_MF, color= self.Colors[self.SIMdata.I_CoilSections.shape[1]+2])
+                legend.append("$I_{Sim,CLIQ}$")
+                ax.plot(self.TDMSdata.TimeFrame_MF, self.TDMSdata.I_CLIQ, color=self.Colors[self.SIMdata.I_CoilSections.shape[1]+2])
+                legend.append("$I_{Meas,CLIQ}$")
+            ax.plot(self.TDMSdata.TimeFrame_MF, self.TDMSdata.I_DCCT_MF, color= self.Colors[self.SIMdata.I_CoilSections.shape[1]+3])
             legend.append("$I_{Meas}$")
             ax.grid(True)
             ax.set_ylabel("Current [A]", fontsize=20)
@@ -519,5 +623,5 @@ class QuenchPlanAnalysis():
                          np.amax([np.amax(self.SIMdata.I_CoilSections),np.amax(self.SIMdata.I_CLIQ), np.amax(self.TDMSdata.I_DCCT_MF)])*1.1])
             ax.set_xlim([0, np.amax([np.amax(self.TDMSdata.TimeFrame_MF), np.amax(self.SIMdata.TimeFrame)])])
             ax.legend(legend,fontsize=20)
-            # ax.set_title("Currents ")
+            ax.set_title(self.TDMSdata.FileName[-13:])
         return [self.TDMSdata, self.SIMdata]
\ No newline at end of file
