@@ -172,12 +172,11 @@ class ParametersCOSIM:
                 makeCopyFile(fileName_complementaryIOPortDefinition,
                              os.path.join(nameFolderCosimModel, 'LEDET'+str(i), 'LedetInputOutputPortDefinition.json'))
 
-    def makeGenericIOPortFiles(self, CoilSections, CoSimFolder: str, PSpiceExecutable: str, LEDETExecutable: str,
+    def makeGenericIOPortFiles(self, CoilSections, CurrentFolder, CoSimFolder: str, PSpiceExecutable: str, LEDETExecutable: str,
                                t_0 = [0, 2e-5], t_end = [2e-5, 0.5], t_step_max = [[1e-5, 1e-5], [1e-5, 1e-5]],
                                relTolerance = [1e-4, None], absTolerance = [1, None], executionOrder = [1, 2],
                                executeCleanRun = [True, True], N_LEDET = 1, QuenchMagnet = 0, SimulationNumber = [0], DistinctMagnets = 1, PSPICEinitialConditions = []):
 
-        CurrentFolder =  os.getcwd()
         # Components which are used in the Ports
         Components = ["L", "CoilSections"]  # [0] = PSpice, [1]=LEDET
         # Setting the Coilsections
@@ -214,7 +213,8 @@ class ParametersCOSIM:
         try:
             os.remove(filename)
         except:
-            print('Already cleaned')
+            # print('Already cleaned')
+            pass
         data = {"coSimulationDir": CoSimFolder}
         data["coSimulationModelSolvers"] = ["PSPICE", "LEDET"]
         data["coSimulationModelDirs"] = [PSpiceFolder, LedetFolder]
@@ -250,7 +250,8 @@ class ParametersCOSIM:
         try:
             os.remove(filename)
         except:
-            print('Already cleaned')
+            #print('Already cleaned')
+            pass
         with open(filename, 'w') as f:
             json.dump(data, f, indent=4)
 
@@ -265,7 +266,8 @@ class ParametersCOSIM:
             try:
                 os.remove(filename)
             except:
-                print('Already cleaned')
+                # print('Already cleaned')
+                pass
             with open(filename, 'w') as f:
                 json.dump(data, f, indent=4)
         else:
@@ -286,7 +288,8 @@ class ParametersCOSIM:
                 try:
                     os.remove(filename)
                 except:
-                    print('Already cleaned')
+                    # print('Already cleaned')
+                    pass
                 with open(filename, 'w') as f:
                     json.dump(data, f, indent=4)
 
@@ -296,7 +299,8 @@ class ParametersCOSIM:
             try:
                 os.remove(filename)
             except:
-                print('Already cleaned')
+                # print('Already cleaned')
+                pass
 
             struct_total = []
             for i in range(len(CoilSections)):  # Number of Ports
@@ -340,7 +344,8 @@ class ParametersCOSIM:
                 try:
                     os.remove(filename)
                 except:
-                    print('Already cleaned')
+                    # print('Already cleaned')
+                    pass
 
                 struct_total = []
                 for i in range(len(CoilSections)):  # Number of Ports
@@ -384,7 +389,8 @@ class ParametersCOSIM:
         try:
             os.remove(filename)
         except:
-            print('Already cleaned')
+            # print('Already cleaned')
+            pass
 
         struct_total = []
         for n in range(0, N_LEDET):
